@@ -3,9 +3,10 @@ Test Keyphrase CRUD endpoints
 """
 import uuid
 
-from workflows_core.utils import DocumentList
+from workflows_core.utils import List
 from workflows_core.dataset.dataset import Dataset
 from workflows_core.api.client import Client
+from workflows_core.utils.keyphrase import Keyphrase
 
 # write a few tests
 class TestClient:
@@ -13,18 +14,12 @@ class TestClient:
         self,
         test_client: Client,
         test_keyphrase_dataset: Dataset,
-        test_keyphrases: DocumentList,
+        test_keyphrases: List[Keyphrase],
     ):
         # Test that upserting keyphrases is good
         field = "sample_1_label"
         alias = "default"
         test_dataset_id = test_keyphrase_dataset.dataset_id
-        keyphrase_id = str(uuid.uuid4())
-        keyphrase_ids = []
-        for d in test_keyphrases:
-            keyphrase_id = str(uuid.uuid4())
-            keyphrase_ids.append(keyphrase_id)
-            d["_id"] = keyphrase_id
 
         result = test_client._api._bulk_update_keyphrase(
             dataset_id=test_dataset_id,
@@ -34,6 +29,7 @@ class TestClient:
         )
         # Now that that we saw the actual dataset
         result = test_client._api._get_keyphrase(
-            test_dataset_id, field=field, alias=alias, keyphrase_id=keyphrase_id
+            test_dataset_id, field=field, alias=alias, keyphrase_id="word"
         )
-        assert result["keyphrase"] == "word" and result["score"] == 10, result
+        print(result)
+        assert result["text"] == "word" and result["keyphrase_score"] == 10, result
