@@ -1,15 +1,19 @@
 """
 Config class
 """
-import argparse
-import base64
-import json
 import uuid
+import json
+import base64
+import argparse
+
 from typing import Optional, List
 from workflows_core.workflow.helpers import decode_workflow_token
 
 from pydantic import BaseModel, Field
-from pydantic.schema import schema
+
+
+def generate_random_string():
+    return str(uuid.uuid4())
 
 
 class BaseConfig(BaseModel):
@@ -30,7 +34,9 @@ class BaseConfig(BaseModel):
 
     authorizationToken: str = None
     dataset_id: Optional[str] = None
-    job_id: Optional[str] = Field(default=str(uuid.uuid4()), description="the job ID")
+    job_id: Optional[str] = Field(
+        default_factory=generate_random_string, description="the job ID"
+    )
     total_workers: Optional[int] = Field(default=None, description="Total workers.")
     send_email: Optional[bool] = Field(
         default=True,
@@ -107,10 +113,13 @@ class BaseTransformConfig(BaseConfig):
         description="If True, re-runs the workflow on the entire dataset.",
     )
     output_to_status: Optional[bool] = Field(
-        default=False,
-        description="If True, it will output results to status object."
+        default=False, description="If True, it will output results to status object."
     )
     documents: Optional[List[object]] = Field(
-        default_factory= lambda: [],
-        description="If passed in, documents will be used instead of dataset."
+        default_factory=lambda: [],
+        description="If passed in, documents will be used instead of dataset.",
+    )
+    limit_documents: Optional[int] = Field(
+        default=None,
+        description="If passed in, the transform will be limited to the number of documents specified here",
     )
